import com.ocrwebservice.client.*;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;

/*
 * 
 * Sample class for OCRWebService.com 
 * 
 */
public class WebServiceClient {

	public static void main(String[] args) {
		
		System.out.println("Process document using OCRWebService.com.\n");
		
	    OCRWebService OCRservice = new OCRWebService();
		
	    OCRWebServiceSoap soap = OCRservice.getOCRWebServiceSoap();

	    // Input image
	    OCRWSInputImage input_image = new OCRWSInputImage();
        
        Path path = Paths.get("C:\\sample_image.jpg");
        
        byte[] data = null;
        try {
			data = Files.readAllBytes(path);
		} catch (IOException e) {
			System.out.println("Exception occured:" + e.getMessage());
			e.printStackTrace();
			return;
		}
	    
        // Set file name
        input_image.setFileName("sample_image.jpg");
        
        // Set file data
        input_image.setFileData(data);
        
        // OCR Settings
        OCRWSSettings ocrwsSetting = new OCRWSSettings();
        
        // Convert to Black/White. May be set TRUE for color images or photos 
        ocrwsSetting.setConvertToBW(false);

        // Return extracted text
        ocrwsSetting.setGetOCRText(true);

        // Set recognition language
        List<OCRWSLanguage> langs =  ocrwsSetting.getOcrLanguages();
        langs.add(OCRWSLanguage.ENGLISH);
        
        // Create and return output file
        ocrwsSetting.setCreateOutputDocument(true);
        
        // Output document format
        ocrwsSetting.setOutputDocumentFormat(OCRWSOutputFormat.DOC);
        
        /* Setup zonal OCR
        ArrayOfOCRWSZone zone_array = new ArrayOfOCRWSZone(); 
        
        OCRWSZone ocrZone = new OCRWSZone();                            
        ocrZone.setTop(0);
        ocrZone.setLeft(0);
        ocrZone.setHeight(400);
        ocrZone.setWidth(400);

        zone_array.getOCRWSZone().add(ocrZone);
        
        ocrwsSetting.setOcrZones(zone_array);
		*/

        
        /* For multipage document recognition
        ocrwsSetting.setMultiPageDoc(true);          
        
        ocrwsSetting.setPageNumbers("1,3,5-12");      	// Enter page numbers and/or page ranges separated by commas. 
                                                    	// "1,3,5-10"   - 1,3,5,6,7,8,9,10 pages will be converted
                                                    	// "-5"         - from first to fifth pages will be converted
                                                    	// "5-"         - from fifth to end document
         
        ocrwsSetting.setPageNumbers("all pages");      	// All pages will be converted
        */
        
        // Convert image
        // Provide your username and license code
        OCRWSResponse response = soap.ocrWebServiceRecognize("<username>", "<license code>", input_image, ocrwsSetting);
        
        // If error occurred
        if (response.getErrorMessage() != null) {
        	System.out.println("Error from OCRWebService: " + response.getErrorMessage());
        	return;
        }
        
        ArrayOfArrayOfString OCRedText = response.getOcrText();

        // Get converter output file
        if (response.getFileData() != null && response.getFileData().length > 0)  {
        	
        	Path output_path = Paths.get("C:\\output\\" + response.getFileName());
  			try {
				Files.write(output_path, response.getFileData());
			} catch (IOException e)	{
				System.out.println("Exception occured:" + e.getMessage());
				e.printStackTrace();
			}
        }

        // Get extracted text
        // OCRedText[z][p]    z - zone, p - pages (for multipage mode)
        for (int z = 0; z < OCRedText.getArrayOfString().size(); z++) {
	        	for (int p = 0; p < OCRedText.getArrayOfString().get(z).getString().size(); p++ ) 	{
	        		System.out.println(String.format("page %d, zone %d: %s", p, z, OCRedText.getArrayOfString().get(z).getString().get(p)));
	        	}
	        }
        }
        
	}

